%global repo_name vcpkg-tool
%global repo_tag 2023-04-07

# imported from Fedora

Name: vcpkg
Version: %(echo %{repo_tag} | sed 's/-/./g')
Release: %mkrel 2

License: MIT
Summary: C++ Library Manager
URL: https://github.com/microsoft/%{repo_name}
Source0: %{url}/archive/%{repo_tag}/%{name}-%{version}.tar.gz
Source1: %{name}.sh
Group: Development/C++

BuildRequires: cmake(catch2)
BuildRequires: cmake
BuildRequires: cmrc-devel
BuildRequires: fmt-devel >= 9.1.0
BuildRequires: ninja

Requires: cmake
Requires: gcc-c++
Requires: git-core
Requires: ninja

Recommends: aria2

%description
Vcpkg is a package manager for the different C and C++ libraries.

Vcpkg can collect usage data. The data collected by Microsoft is anonymous.

This package has telemetry disabled by default. If you want to enable
telemetry, you should remove the %{_sysconfdir}/profile.d/%{name}.sh file
or unset the VCPKG_DISABLE_METRICS environment variable.

%prep
%autosetup -n %{repo_name}-%{repo_tag} -p1

# Fixing line endings...
sed -e "s,\r,," -i README.md

# Unbundling catch...
rm -rf include/catch2
ln -svf %{_includedir}/catch2/ include/


%build
%cmake -G Ninja \
    -DCMAKE_BUILD_TYPE=Release \
    -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
    -DBUILD_TESTING:BOOL=OFF \
    -DVCPKG_BASE_VERSION:STRING=%{repo_tag} \
    -DVCPKG_VERSION:STRING=%{repo_tag} \
    -DVCPKG_DEVELOPMENT_WARNINGS:BOOL=OFF \
    -DVCPKG_WARNINGS_AS_ERRORS:BOOL=OFF \
    -DVCPKG_DEPENDENCY_CMAKERC:BOOL=ON \
    -DVCPKG_DEPENDENCY_EXTERNAL_FMT:BOOL=ON \
    -DVCPKG_BUILD_TLS12_DOWNLOADER:BOOL=OFF \
    -DVCPKG_BUILD_FUZZING:BOOL=OFF \
    -DVCPKG_EMBED_GIT_SHA:BOOL=OFF \
    -DVCPKG_BUILD_BENCHMARKING:BOOL=OFF \
    -DVCPKG_ADD_SOURCELINK:BOOL=OFF
%cmake_build

%install
%cmake_install

# Installing environment options override...
install -D -m 0644 -p "%{SOURCE1}" "%{buildroot}%{_sysconfdir}/profile.d/%{name}.sh"

%files
%doc README.md
%license LICENSE.txt NOTICE.txt
%{_bindir}/%{name}
%config(noreplace) %{_sysconfdir}/profile.d/%{name}.sh
